package com.afp.ordermanagement.service;

import com.afp.ordermanagement.model.Order;
import com.afp.ordermanagement.model.OrderStatus;
import org.springframework.mail.SimpleMailMessage;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.stereotype.Service;

@Service
public class EmailService {
    private JavaMailSender javaMailSender;

    public EmailService(JavaMailSender javaMailSender) {
        this.javaMailSender = javaMailSender;
    }

    public void sendMail(String toEmail, String subject, String message) {

        SimpleMailMessage mailMessage = new SimpleMailMessage();

        mailMessage.setTo(toEmail);
        mailMessage.setSubject(subject);
        mailMessage.setText(message);

        mailMessage.setFrom("NOREPLY@nisum.com");

        javaMailSender.send(mailMessage);
    }

    public String messageCreator(Order order) {
        OrderStatus status = order.getOrderStatus();
        String message1 = "message ", message2 = "build failed.";
        switch (status) {
            case RECEIVED:
                message1 = "Hello, you order #" + order.getId() + " has been received!";
                message2 = "We hope to have your order fulfilled soon.";
                break;
            case CANCELLED:
                message1 = "I'm sorry, your order #" + order.getId() + " has been canceled.";
                message2 = "For more information, contact {NULL}.";
                break;
            case FULFILLED:
                message1 = "Good news everyone! Your order #" + order.getId() + " has been fulfilled.";
                message2 = "Your tracking number is: " + order.getOrderTrackingCode();
                break;
        }
        return message1 + message2;
    }

    public String subjectCreator(Order order) {
        String status = "NULL";
        switch (order.getOrderStatus()) {
            case RECEIVED:
                status = "RECEIVED";
                break;
            case CANCELLED:
                status = "CANCELLED";
                break;
            case FULFILLED:
                status = "FULFILLED";
                break;
        }
        return "Your order #" + order.getId() + " has been" + status;
    }

    public String toCreator(Order order) {
        return order.getCustomerEmailAddress();
    }

    public String emailCreator(Order order) {
        String message = messageCreator(order);
        String subject = subjectCreator(order);
        String to = toCreator(order);

        sendMail(to, subject, message);
        return "Email sent to customer!";
    }
}
